@@ -97,6 +97,7 @@ static void *funcs[] = {
 	HX_split,
 	HX_split4,
 	HX_split5,
+	HX_stpltrim,
 	HX_strbchr,
 	HX_strchr2,
 	HX_strclone,
@@ -116,16 +117,24 @@ static void *funcs[] = {
 	HX_strsep2,
 	HX_strquote,
 	HX_strupper,
-	HX_diff_timespec,
+#ifdef HAVE_STRUCT_TIMEVAL_TV_USEC
 	HX_diff_timeval,
+#endif
+#ifdef HAVE_STRUCT_TIMESPEC_TV_NSEC
+	HX_diff_timespec,
+#endif
 	HX_time_compare,
+#ifdef HAVE_STRUCT_TIMESPEC_TV_NSEC
 	HX_timespec_add,
 	HX_timespec_isneg,
 	HX_timespec_mul,
 	HX_timespec_mulf,
 	HX_timespec_neg,
 	HX_timespec_sub,
+#endif
+#ifdef HAVE_STRUCT_TIMEVAL_TV_USEC
 	HX_timeval_sub,
+#endif
 #ifdef _WIN32
 	chown,
 	fchmod,
@@ -148,6 +157,6 @@ int main(void)
 	for (i = 0; i < ARRAY_SIZE(funcs); ++i)
 		printf("%p ", funcs[i]);
 	printf("\n");
-	printf("There are %zu exported functions\n", ARRAY_SIZE(funcs));
+	printf("There are %" HX_SIZET_FMT "u exported functions\n", ARRAY_SIZE(funcs));
 	return EXIT_SUCCESS;
 }
